@@ -204,8 +204,8 @@ it's not cached."
 	      ;; [number subject from date id references chars lines xref]
 	      (insert (format "%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t\n"
 			      (mail-header-number headers)
-			      (mime-fetch-field 'Subject headers)
-			      (mime-fetch-field 'From headers)
+			      (mime-entity-fetch-field headers 'Subject)
+			      (mime-entity-fetch-field headers 'From)
 			      (mail-header-date headers)
 			      (mail-header-id headers)
 			      (or (mail-header-references headers) "")
